@@ -1,25 +1,13 @@
 from operator import itemgetter
 import subprocess
-import yaml
 import arrow
-import json
-import pipes
-import re
-import traceback
 import sys
 import shutil
-import hashlib
-import os
 import tempfile
 import click
-import inquirer
-from datetime import datetime
-from .tools import remove_webassets
-from .tools import _askcontinue
 from .tools import __dc
-from .tools import get_volume_names
 from .tools import search_env_path
-from . import cli, pass_config, Commands
+from . import cli, pass_config
 from .lib_clickhelpers import AliasedGroup
 from .tools import __hash_odoo_password
 from pathlib import Path
@@ -129,7 +117,7 @@ def _turn_into_subvolume(path):
             finally:
                 subprocess.check_call(["sudo", "rm", "-Rf", filename])
         else:
-            raise
+            raise Exception("Unexpected error at turning into subvolume")
     else:
         return
 
@@ -208,3 +196,22 @@ def remove(config, snapshot):
                 str(snapshot["path"]),
             ]
         )
+
+def purge_inactive(config):
+    for vol in SNAPSHOT_DIR.glob("*"):
+        if not vol.is_dir():
+            continue
+        try:
+            next(DOCKER_VOLUMES.glob(vol.name))
+        except StopIteration:
+            for snapshot in vol.glob("*"):
+                subprocess.check_call(
+                    [
+                        "sudo",
+                        "btrfs",
+                        "subvolume",
+                        "delete",
+                        str(snapshot)
+                    ]
+                )
+            shutil.rmtree(vol)
